/*******************************************************************************
 * The MIT License
 * 
 * Copyright (c) 2009 OpenCGD Project
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 ******************************************************************************/
package opencgd.server.io.frames;

import opencgd.server.SessionManager;
import opencgd.server.io.Frame;
import opencgd.server.io.FrameReader;
import opencgd.server.io.FrameWriter;
import opencgd.server.io.IFrameHandler;
import opencgd.server.io.ISession;
import opencgd.server.model.Player;

import org.grlea.log.SimpleLogger;

class ChatMessage implements IFrameHandler {
	
	private static final SimpleLogger LOGGER = new SimpleLogger(ChatMessage.class);

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int getID(){
		return 3;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void process(Frame frame, FrameReader reader, Player context){
		final String message = new String(reader.getData());
		LOGGER.info("Chat message ("+context.getName()+"): "+message);
		
		/*
		 * if lobby -> put in lobby chat
		 * else -> put in room chat (wherever the context is located at)
		 */
		
		if(message.charAt(0) == '/'){ //Command handle
			final String command = message.substring(1);
			
			if(command.equals("chreq")){
				final FrameWriter response = new FrameWriter(9);
				response.addShort(2); //Index of waitingList
				response.addShort(4); //Time per move l[o];
				response.addShort(1); //Nonrated(0)/Rated(1)
				context.sendFrame(response);
			}
		} else {
			//XXX For now (testing) just assume it's global (which it wont ever be)
			final FrameWriter chatMsg = new FrameWriter(8);
			final String formatted = context.getName()+": "+message;
			chatMsg.addBytes(formatted.getBytes());
			
			for(ISession session : SessionManager.getInstance().getSessions()){
				if(session.isLoggedIn()){
					session.sendFrame(chatMsg);
				}
			}
		}
	}
}
