/*******************************************************************************
 * The MIT License
 * 
 * Copyright (c) 2009 OpenCGD Project
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 ******************************************************************************/
package opencgd.server.io.frames;

import java.util.ArrayList;
import java.util.List;

import opencgd.server.io.Frame;
import opencgd.server.io.FrameReader;
import opencgd.server.io.IFrameHandler;
import opencgd.server.model.Player;

import org.grlea.log.SimpleLogger;

public class FrameManager {

	private static final FrameManager INSTANCE = new FrameManager();
	private static final SimpleLogger LOGGER = new SimpleLogger(FrameManager.class);
	private final List<IFrameHandler> frameHandlers = new ArrayList<IFrameHandler>();
	
	private FrameManager(){
		frameHandlers.add(new Ping()); //0
		frameHandlers.add(new Disconnect()); //1
		frameHandlers.add(new ChatMessage()); //3
		frameHandlers.add(new SetMatchOptions()); //5
		frameHandlers.add(new ChallengePlayer()); //6
		frameHandlers.add(new EnterGame()); //15
		frameHandlers.add(new ChangeGame()); //16
	}
	
	public void process(Frame frame, FrameReader reader, Player context){
		for(IFrameHandler handler : frameHandlers){
			if(handler.getID() == frame.getID()){
				handler.process(frame, reader, context);
				return;
			}
		}
		
		//No frame handler installed for this ID
		LOGGER.warn("Unhandled frame: ID="+frame.getID()+", Size="+frame.getSize());
	}

	public static FrameManager getInstance(){
		return INSTANCE;
	}

	public List<IFrameHandler> getFrameHandlers(){
		return frameHandlers;
	}
}
